@@ -11,7 +11,7 @@ from aiohttp import http
 from aiohttp.client import ClientSession
 from aiohttp.client_reqrep import ClientResponse
 from ddt import ddt, data
-from pkg_resources import parse_version
+from packaging.version import Version
 
 try:
     from aiohttp.errors import (
@@ -31,6 +31,8 @@ from aioresponses import CallbackResult, aioresponses
 from .base import fail_on, skipIf, AsyncTestCase
 
 
+MINIMUM_AIOHTTP_VERSION = Version('3.4.0')
+
 @ddt
 class AIOResponsesTestCase(AsyncTestCase):
 
@@ -118,7 +120,7 @@ class AIOResponsesTestCase(AsyncTestCase):
         self.assertEqual(cm.exception.message, http.RESPONSES[400][0])
 
     @aioresponses()
-    @skipIf(condition=AIOHTTP_VERSION < parse_version('3.4.0'),
+    @skipIf(condition=AIOHTTP_VERSION < MINIMUM_AIOHTTP_VERSION,
             reason='aiohttp<3.4.0 does not support raise_for_status '
                    'arguments for requests')
     async def test_request_raise_for_status(self, m):
@@ -333,7 +335,7 @@ class AIOResponsesTestCase(AsyncTestCase):
                         callback=lambda *_, **__: callback_called.set())
             with self.assertRaises(HttpProcessingError):
                 await self.session.get(url)
-            
+
             await callback_called.wait()
 
     async def test_multiple_requests(self):
@@ -664,7 +666,7 @@ class AIOResponsesRaiseForStatusSessionTestCase(AsyncTestCase):
         self.assertEqual(cm.exception.message, http.RESPONSES[400][0])
 
     @aioresponses()
-    @skipIf(condition=AIOHTTP_VERSION < parse_version('3.4.0'),
+    @skipIf(condition=AIOHTTP_VERSION < MINIMUM_AIOHTTP_VERSION,
             reason='aiohttp<3.4.0 does not support raise_for_status '
                    'arguments for requests')
     async def test_do_not_raise_for_status(self, m):
@@ -742,8 +744,6 @@ class AIOResponseRedirectTest(AsyncTestCase):
         self.assertEqual(str(response.url), self.url)
 
     @aioresponses()
-    @skipIf(condition=AIOHTTP_VERSION < parse_version('3.1.0'),
-            reason='aiohttp<3.1.0 does not add request info on response')
     async def test_request_info(self, rsps):
         rsps.get(self.url, status=200)
 
@@ -754,8 +754,6 @@ class AIOResponseRedirectTest(AsyncTestCase):
         assert request_info.headers == {}
 
     @aioresponses()
-    @skipIf(condition=AIOHTTP_VERSION < parse_version('3.1.0'),
-            reason='aiohttp<3.1.0 does not add request info on response')
     async def test_request_info_with_original_request_headers(self, rsps):
         headers = {"Authorization": "Bearer access-token"}
         rsps.get(self.url, status=200)
